============
Installation
============

At the command line::

    $ easy_install langchangetrack

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv langchangetrack
    $ pip install langchangetrack
